@@ -61,6 +61,7 @@ func (c *Context) createFuncMap() template.FuncMap {
 		"envExec":          c.EnvExec,
 		"exec":             c.Exec,
 		"isFile":           c.IsFile,
+		"isDir":            c.IsDir,
 		"readFile":         c.ReadFile,
 		"readDir":          c.ReadDir,
 		"readDirEntries":   c.ReadDirEntries,
@@ -229,6 +230,24 @@ func (c *Context) IsFile(filename string) (bool, error) {
 	return false, err
 }
 
+func (c *Context) IsDir(filename string) (bool, error) {
+	var path string
+	if filepath.IsAbs(filename) {
+		path = filename
+	} else {
+		path = filepath.Join(c.basePath, filename)
+	}
+
+	stat, err := os.Stat(path)
+	if err == nil {
+		return stat.IsDir(), nil
+	}
+	if errors.Is(err, os.ErrNotExist) {
+		return false, nil
+	}
+	return false, err
+}
+
 func (c *Context) ReadFile(filename string) (string, error) {
 	var path string
 	if filepath.IsAbs(filename) {
